Monitorex.Collector (monitorex v0.3.0)

GenServer that owns ETS tables, attaches telemetry handlers, and runs periodic maintenance for the Monitorex monitoring system.

Summary

Functions

Returns a specification to start this module under a supervisor.

Handles a telemetry event by writing it to the appropriate ETS tables. Called by telemetry handlers.

Starts the Collector GenServer.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

handle_event(event, pid \\ __MODULE__)

Handles a telemetry event by writing it to the appropriate ETS tables. Called by telemetry handlers.

start_link(opts \\ [])

Starts the Collector GenServer.