Monitorex.Collector
(monitorex v0.3.0)
GenServer that owns ETS tables, attaches telemetry handlers, and runs periodic maintenance for the Monitorex monitoring system.
Summary
Functions
Returns a specification to start this module under a supervisor.
Handles a telemetry event by writing it to the appropriate ETS tables. Called by telemetry handlers.
Starts the Collector GenServer.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.
Handles a telemetry event by writing it to the appropriate ETS tables. Called by telemetry handlers.
Starts the Collector GenServer.